# Generated by Django 4.2.13 on 2024-07-11 10:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("djangoldp_dashboard", "0008_alter_dashboard_options_alter_dashboard_urlid"),
    ]

    operations = [
        migrations.AlterField(
            model_name="dashboard",
            name="size",
            field=models.CharField(
                choices=[
                    ("1", "1"),
                    ("12", "1/2"),
                    ("13", "1/3"),
                    ("14", "1/4"),
                    ("23", "2/3"),
                    ("24", "2/4"),
                    ("34", "3/4"),
                ],
                default="1",
                max_length=2,
            ),
        ),
    ]
