# Generated by Django 4.2.13 on 2024-07-01 10:55

from django.db import migrations
import djangoldp.fields


class Migration(migrations.Migration):

    dependencies = [
        ("djangoldp_dashboard", "0007_auto_20210223_2254"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="dashboard",
            options={
                "default_permissions": {"control", "add", "delete", "change", "view"}
            },
        ),
        migrations.AlterField(
            model_name="dashboard",
            name="urlid",
            field=djangoldp.fields.LDPUrlField(
                blank=True, db_index=True, null=True, unique=True
            ),
        ),
    ]
