# Generated by Django 4.2.13 on 2024-07-11 13:25

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("djangoldp_dashboard", "0009_alter_dashboard_size"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="dashboard",
            options={
                "default_permissions": {"add", "view", "delete", "control", "change"},
                "ordering": ["target"],
                "verbose_name": "Dashboard",
                "verbose_name_plural": "Dashboards",
            },
        ),
    ]
