# Generated by Django 4.2.13 on 2024-07-11 13:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("djangoldp_dashboard", "0010_alter_dashboard_options"),
    ]

    operations = [
        migrations.AddField(
            model_name="dashboard",
            name="order",
            field=models.IntegerField(blank=True, null=True),
        ),
    ]
